==> haskell-warp-3.4.0-10-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-warp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 warp
version:              3.4.0
visibility:           public
id:                   warp-3.4.0-EMEx6bSExsO4TCzNcPaO2H
key:                  warp-3.4.0-EMEx6bSExsO4TCzNcPaO2H
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Kazu Yamamoto, Matt Brown
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             A fast, light-weight web server for WAI applications.
description:
    HTTP\/1.0, HTTP\/1.1 and HTTP\/2 are supported.
    For HTTP\/2,  Warp supports direct and ALPN (in TLS)
    but not upgrade.
    API docs and the README are available at
    <http://www.stackage.org/package/warp>.

category:             Web, Yesod
abi:                  9e3d53b6586baa03f0b50f13994208e1
exposed:              True
exposed-modules:
    Network.Wai.Handler.Warp Network.Wai.Handler.Warp.Internal

hidden-modules:
    Network.Wai.Handler.Warp.Buffer Network.Wai.Handler.Warp.Conduit
    Network.Wai.Handler.Warp.Counter Network.Wai.Handler.Warp.Date
    Network.Wai.Handler.Warp.FdCache Network.Wai.Handler.Warp.File
    Network.Wai.Handler.Warp.FileInfoCache
    Network.Wai.Handler.Warp.HashMap Network.Wai.Handler.Warp.HTTP1
    Network.Wai.Handler.Warp.HTTP2 Network.Wai.Handler.Warp.HTTP2.File
    Network.Wai.Handler.Warp.HTTP2.PushPromise
    Network.Wai.Handler.Warp.HTTP2.Request
    Network.Wai.Handler.Warp.HTTP2.Response
    Network.Wai.Handler.Warp.HTTP2.Types
    Network.Wai.Handler.Warp.Header Network.Wai.Handler.Warp.IO
    Network.Wai.Handler.Warp.Imports Network.Wai.Handler.Warp.PackInt
    Network.Wai.Handler.Warp.ReadInt Network.Wai.Handler.Warp.Request
    Network.Wai.Handler.Warp.RequestHeader
    Network.Wai.Handler.Warp.Response
    Network.Wai.Handler.Warp.ResponseHeader
    Network.Wai.Handler.Warp.Run Network.Wai.Handler.Warp.SendFile
    Network.Wai.Handler.Warp.Settings Network.Wai.Handler.Warp.Types
    Network.Wai.Handler.Warp.Windows
    Network.Wai.Handler.Warp.WithApplication Paths_warp
    Network.Wai.Handler.Warp.MultiMap

import-dirs:          /usr/lib/ghc-9.6.6/site-local/warp-3.4.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/warp-3.4.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/warp-3.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp
hs-libraries:         HSwarp-3.4.0-EMEx6bSExsO4TCzNcPaO2H
depends:
    array-0.5.6.0 auto-update-0.1.6-88T3ReDBoup7kx6uceSFG6
    base-4.18.2.1 bsb-http-chunked-0.0.0.4-JbicF0VXWO21sFJBFg8iSz
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-KNymwxzPyypAOJSQGx0ioI
    containers-0.6.7 crypton-x509-1.7.7-6vuhyPxGrsd7bUuwSROapz
    ghc-prim-0.10.0 hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    http-date-0.0.11-9AFt6UkMptmCfRQJmnvzGs
    http-types-0.12.4-E9He9FXy4rKITKDtg1mhVt
    http2-5.1.0-FK6XJLktFe6k5n0BrphKA
    iproute-1.7.15-G8PIBt0bMmIHonL1qb456T
    network-3.1.4.0-JRitsFhJ8rKGUNW13KrLgQ
    recv-0.1.1-2zF7O1pwsoXGqfuMlLk1gB
    simple-sendfile-0.2.32-JPaaq7o1SU0xatHlb8xiw stm-2.5.1.0
    streaming-commons-0.2.3.1-J8SxFARI4BPDYt3Np6OVv5 text-2.0.2
    time-manager-0.0.1-J7X2oj44VWZ1BlIeM6DdG7 unix-2.8.4.0
    unliftio-0.2.25.1-6Q6KWrgvoh1DxBXv7luml2
    vault-0.3.1.5-A9Ty7yzuPZlIa80zuSIl14
    wai-3.2.4-DggAE0S6Fb43aX3BIvUJ63 word8-0.1.3-7y8d2ts6b899pqfTpiB4ap

haddock-interfaces:   /usr/share/doc/haskell-warp/html/warp.haddock
haddock-html:         /usr/share/doc/haskell-warp/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-warp-3.4.0-12-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-warp.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 warp
version:              3.4.0
visibility:           public
id:                   warp-3.4.0-Js0YTJVu1i5Lh7vUHNAyGE
key:                  warp-3.4.0-Js0YTJVu1i5Lh7vUHNAyGE
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Kazu Yamamoto, Matt Brown
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             A fast, light-weight web server for WAI applications.
description:
    HTTP\/1.0, HTTP\/1.1 and HTTP\/2 are supported.
    For HTTP\/2,  Warp supports direct and ALPN (in TLS)
    but not upgrade.
    API docs and the README are available at
    <http://www.stackage.org/package/warp>.

category:             Web, Yesod
abi:                  00d0f6c22d6224d1e5cad377eb4e1ae2
exposed:              True
exposed-modules:
    Network.Wai.Handler.Warp Network.Wai.Handler.Warp.Internal

hidden-modules:
    Network.Wai.Handler.Warp.Buffer Network.Wai.Handler.Warp.Conduit
    Network.Wai.Handler.Warp.Counter Network.Wai.Handler.Warp.Date
    Network.Wai.Handler.Warp.FdCache Network.Wai.Handler.Warp.File
    Network.Wai.Handler.Warp.FileInfoCache
    Network.Wai.Handler.Warp.HashMap Network.Wai.Handler.Warp.HTTP1
    Network.Wai.Handler.Warp.HTTP2 Network.Wai.Handler.Warp.HTTP2.File
    Network.Wai.Handler.Warp.HTTP2.PushPromise
    Network.Wai.Handler.Warp.HTTP2.Request
    Network.Wai.Handler.Warp.HTTP2.Response
    Network.Wai.Handler.Warp.HTTP2.Types
    Network.Wai.Handler.Warp.Header Network.Wai.Handler.Warp.IO
    Network.Wai.Handler.Warp.Imports Network.Wai.Handler.Warp.PackInt
    Network.Wai.Handler.Warp.ReadInt Network.Wai.Handler.Warp.Request
    Network.Wai.Handler.Warp.RequestHeader
    Network.Wai.Handler.Warp.Response
    Network.Wai.Handler.Warp.ResponseHeader
    Network.Wai.Handler.Warp.Run Network.Wai.Handler.Warp.SendFile
    Network.Wai.Handler.Warp.Settings Network.Wai.Handler.Warp.Types
    Network.Wai.Handler.Warp.Windows
    Network.Wai.Handler.Warp.WithApplication Paths_warp
    Network.Wai.Handler.Warp.MultiMap

import-dirs:          /usr/lib/ghc-9.6.6/site-local/warp-3.4.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/warp-3.4.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/warp-3.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-warp
hs-libraries:         HSwarp-3.4.0-Js0YTJVu1i5Lh7vUHNAyGE
depends:
    array-0.5.6.0 auto-update-0.1.6-KtJVhP9gwX02GwwOhHipKc
    base-4.18.2.1 bsb-http-chunked-0.0.0.4-2qmdsqrGFFr4JFUzDLkwnq
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-8PStX6cixKCLkUJoPuARL
    containers-0.6.7 crypton-x509-1.7.7-EHBNyCbrbA07dcTqixBZKh
    ghc-prim-0.10.0 hashable-1.4.7.0-LSmBhr9Bt59DsIlhOBFmCL
    http-date-0.0.11-4ysForz95Bd3k30KUutCqj
    http-types-0.12.4-2YF0olXF9itCctWavExzmH
    http2-5.1.0-6rnz1E5Vv69HopbACkUkoK
    iproute-1.7.15-3GkfBOWcvcU41ReIxtPoLT
    network-3.1.4.0-xB4epdb1XO3ZKzAxljM4X
    recv-0.1.1-BGi4hrFuNwtDkKnYHj9ng0
    simple-sendfile-0.2.32-KipkB6rqag54fgEJdnaHpA stm-2.5.1.0
    streaming-commons-0.2.3.1-p6JZxPGlgm2ju1b9E77qr text-2.0.2
    time-manager-0.0.1-8HcaIVWEJA24Rv95oE40CY unix-2.8.4.0
    unliftio-0.2.25.1-DOqhOSuyr6GEMTQhxoBZ0V
    vault-0.3.1.5-BxUCdgn4AEk2ZyHGBzL9yO
    wai-3.2.4-BLc210LwMQhDvJHRqgIjev word8-0.1.3-7y8d2ts6b899pqfTpiB4ap

haddock-interfaces:   /usr/share/doc/haskell-warp/html/warp.haddock
haddock-html:         /usr/share/doc/haskell-warp/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
